@@ -36,35 +36,37 @@ seek = [withNothing start]
 {- Finds unused content in the annex. -} 
 start :: CommandStartNothing
 start = notBareRepo $ do
-	showStart "unused" ""
-	next perform
+	from <- Annex.getState Annex.fromremote
+	let (name, action) = case from of
+		Nothing -> (".", checkUnused)
+		Just "." -> (".", checkUnused)
+		Just n -> (n, checkRemoteUnused n)
+	showStart "unused" name
+	next action
 
-perform :: CommandPerform
-perform = do
-	maybe checkUnused checkRemoteUnused =<< Annex.getState Annex.fromremote
-	next $ return True
-
-checkUnused :: Annex ()
+checkUnused :: CommandPerform
 checkUnused = do
 	(unused, stalebad, staletmp) <- unusedKeys
-	n  <- list "" unusedMsg unused 0
-	n' <- list "bad" staleBadMsg stalebad n
-	_  <- list "tmp" staleTmpMsg staletmp n'
-	return ()
+	_ <- list "" unusedMsg unused 0 >>=
+		list "bad" staleBadMsg stalebad >>=
+			list "tmp" staleTmpMsg staletmp
+	next $ return True
 	where
 		list file msg l c = do
 			let unusedlist = number c l
 			when (not $ null l) $ showLongNote $ msg unusedlist
 			writeUnusedFile file unusedlist
-			return $ length l
+			return $ c + length l
 
-checkRemoteUnused :: String -> Annex ()
-checkRemoteUnused name = checkRemoteUnused' =<< Remote.byName name
+checkRemoteUnused :: String -> CommandPerform
+checkRemoteUnused name = do
+	checkRemoteUnused' =<< Remote.byName name
+	next $ return True
 
 checkRemoteUnused' :: Remote.Remote Annex -> Annex ()
 checkRemoteUnused' r = do
+	showNote $ "checking for unused data..."
 	g <- Annex.gitRepo
-	showNote $ "checking for unused data on " ++ Remote.name r ++ "..."
 	referenced <- getKeysReferenced
 	logged <- liftIO $ loggedKeys g
 	remotehas <- filterM isthere logged
